TurnPinger

Struct TurnPinger 

pub struct TurnPinger {
    pub server: String,
    pub timeout: Duration,
}
TURN pinger — sends an unauthenticated Allocate Request to server and considers the expected 401 Unauthorized Allocate Error Response a successful ping (it proves the server is alive and speaks RFC 5766). Default port 3478. Doesn’t actually allocate any relay state, so it’s safe to spam against shared TURN infrastructure.

Fields

server: Stringtimeout: Duration

Implementations

Source

impl TurnPinger

pub fn new(server: impl Into<String>) -> Self

pub fn with_timeout(self, t: Duration) -> Self